pub struct LAEnvironmentMechanismBiometry { /* private fields */ }Expand description
Biometric LAEnvironment mechanism details.
Implementations
Sourceimpl LAEnvironmentMechanismBiometry
impl LAEnvironmentMechanismBiometry
Sourcepub fn is_usable(&self) -> Result<bool>
pub fn is_usable(&self) -> Result<bool>
Whether the mechanism is currently usable for authentication.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn localized_name(&self) -> Result<String>
pub fn localized_name(&self) -> Result<String>
Localized display name such as Touch ID or Face ID.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn icon_system_name(&self) -> Result<String>
pub fn icon_system_name(&self) -> Result<String>
SF Symbol name representing this mechanism.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn biometry_type(&self) -> Result<BiometryType>
pub fn biometry_type(&self) -> Result<BiometryType>
Hardware biometry type supported by the device.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn is_enrolled(&self) -> Result<bool>
pub fn is_enrolled(&self) -> Result<bool>
Whether the user has enrolled this biometric mechanism.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn is_locked_out(&self) -> Result<bool>
pub fn is_locked_out(&self) -> Result<bool>
Whether the biometric mechanism is locked out.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn state_hash(&self) -> Result<Vec<u8>>
pub fn state_hash(&self) -> Result<Vec<u8>>
Application-specific biometric enrollment hash.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn built_in_sensor_inaccessible(&self) -> Result<bool>
pub fn built_in_sensor_inaccessible(&self) -> Result<bool>
Whether the built-in biometric sensor is inaccessible.
Errors
Returns an error if the Swift bridge rejects the request.