pub struct LAEnvironmentMechanismUserPassword { /* private fields */ }Expand description
Password or passcode LAEnvironment mechanism details.
Implementations
Sourceimpl LAEnvironmentMechanismUserPassword
impl LAEnvironmentMechanismUserPassword
Sourcepub fn is_usable(&self) -> Result<bool>
pub fn is_usable(&self) -> Result<bool>
Whether the mechanism is currently usable for authentication.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn localized_name(&self) -> Result<String>
pub fn localized_name(&self) -> Result<String>
Localized display name such as Password.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn icon_system_name(&self) -> Result<String>
pub fn icon_system_name(&self) -> Result<String>
SF Symbol name representing this mechanism.
Errors
Returns an error if the Swift bridge rejects the request.