pub struct LAEnvironmentState { /* private fields */ }Expand description
Snapshot wrapper around Apple’s LAEnvironmentState.
Implementations
Sourceimpl LAEnvironmentState
impl LAEnvironmentState
Sourcepub fn biometry(&self) -> Result<Option<LAEnvironmentMechanismBiometry>>
pub fn biometry(&self) -> Result<Option<LAEnvironmentMechanismBiometry>>
Information about the device’s biometric mechanism, if supported.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn user_password(
&self,
) -> Result<Option<LAEnvironmentMechanismUserPassword>>
pub fn user_password( &self, ) -> Result<Option<LAEnvironmentMechanismUserPassword>>
Information about the local user password or passcode mechanism, if supported.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn companions(&self) -> Result<Vec<LAEnvironmentMechanismCompanion>>
pub fn companions(&self) -> Result<Vec<LAEnvironmentMechanismCompanion>>
Companion authentication mechanisms currently paired with this device.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn all_mechanisms(&self) -> Result<Vec<LAEnvironmentMechanism>>
pub fn all_mechanisms(&self) -> Result<Vec<LAEnvironmentMechanism>>
Information about every currently known authentication mechanism.
Errors
Returns an error if the Swift bridge rejects the request.