pub struct LAPersistedRight { /* private fields */ }Expand description
Managed wrapper around Apple’s LAPersistedRight.
Implementations
Sourceimpl LAPersistedRight
impl LAPersistedRight
Sourcepub fn state(&self) -> Result<LARightState>
pub fn state(&self) -> Result<LARightState>
Sourcepub fn tag(&self) -> Result<i64>
pub fn tag(&self) -> Result<i64>
Application-controlled integer tag.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn set_tag(&self, tag: i64) -> Result<()>
pub fn set_tag(&self, tag: i64) -> Result<()>
Update the application-controlled integer tag.
Errors
Returns an error if the Swift bridge rejects the request.
Attempt to authorize the persisted right.
Errors
Returns a mapped framework or bridge error when authorization fails.
Preflight whether the persisted right can eventually be authorized.
Errors
Returns a mapped framework or bridge error when authorization is not possible.
Sourcepub fn key(&self) -> Result<LAPrivateKey>
pub fn key(&self) -> Result<LAPrivateKey>
Borrow the managed private key associated with this persisted right.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn secret(&self) -> Result<LASecret>
pub fn secret(&self) -> Result<LASecret>
Borrow the generic secret associated with this persisted right.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn public_key(&self) -> Result<LAPublicKey>
pub fn public_key(&self) -> Result<LAPublicKey>
Convenience helper returning self.key()?.public_key().
Errors
Returns an error if the Swift bridge rejects the request.