#[non_exhaustive]pub enum LAPolicy {
DeviceOwnerAuthenticationWithBiometrics,
DeviceOwnerAuthentication,
DeviceOwnerAuthenticationWithCompanion,
DeviceOwnerAuthenticationWithBiometricsOrCompanion,
DeviceOwnerAuthenticationWithWatch,
DeviceOwnerAuthenticationWithBiometricsOrWatch,
}Expand description
Authentication policies supported on macOS by LocalAuthentication.framework.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DeviceOwnerAuthenticationWithBiometrics
Authenticate the device owner using biometry only.
DeviceOwnerAuthentication
Authenticate the device owner using biometry or the local password.
DeviceOwnerAuthenticationWithCompanion
Authenticate the device owner using a nearby companion device.
DeviceOwnerAuthenticationWithBiometricsOrCompanion
Authenticate the device owner using biometry or a nearby companion device.
DeviceOwnerAuthenticationWithWatch
👎Deprecated:
Use DeviceOwnerAuthenticationWithCompanion instead.
Deprecated alias for companion-device authentication.
DeviceOwnerAuthenticationWithBiometricsOrWatch
👎Deprecated:
Use DeviceOwnerAuthenticationWithBiometricsOrCompanion instead.
Deprecated alias for biometry-or-companion authentication.
Implementations