pub type Policy = LAPolicy;Expand description
Backward-compatible alias for the v0.1.x enum name.
Aliased Type
pub enum Policy {
DeviceOwnerAuthenticationWithBiometrics,
DeviceOwnerAuthentication,
DeviceOwnerAuthenticationWithCompanion,
DeviceOwnerAuthenticationWithBiometricsOrCompanion,
DeviceOwnerAuthenticationWithWatch,
DeviceOwnerAuthenticationWithBiometricsOrWatch,
}Variants
DeviceOwnerAuthenticationWithBiometrics
Authenticate the device owner using biometry only.
DeviceOwnerAuthentication
Authenticate the device owner using biometry or the local password.
DeviceOwnerAuthenticationWithCompanion
Authenticate the device owner using a nearby companion device.
DeviceOwnerAuthenticationWithBiometricsOrCompanion
Authenticate the device owner using biometry or a nearby companion device.
DeviceOwnerAuthenticationWithWatch
👎Deprecated:
Use DeviceOwnerAuthenticationWithCompanion instead.
Deprecated alias for companion-device authentication.
DeviceOwnerAuthenticationWithBiometricsOrWatch
👎Deprecated:
Use DeviceOwnerAuthenticationWithBiometricsOrCompanion instead.
Deprecated alias for biometry-or-companion authentication.