pub struct LAPublicKey { /* private fields */ }Expand description
Managed wrapper around Apple’s LAPublicKey.
Implementations
Sourceimpl LAPublicKey
impl LAPublicKey
Sourcepub fn export_bytes(&self) -> Result<Vec<u8>>
pub fn export_bytes(&self) -> Result<Vec<u8>>
Sourcepub fn can_encrypt_using(&self, algorithm: &SecKeyAlgorithm) -> Result<bool>
pub fn can_encrypt_using(&self, algorithm: &SecKeyAlgorithm) -> Result<bool>
Check whether an algorithm can encrypt with this key.
Errors
Returns an error if the Swift bridge rejects the request.
Sourcepub fn can_verify_using(&self, algorithm: &SecKeyAlgorithm) -> Result<bool>
pub fn can_verify_using(&self, algorithm: &SecKeyAlgorithm) -> Result<bool>
Check whether an algorithm can verify signatures with this key.
Errors
Returns an error if the Swift bridge rejects the request.