pub struct SecKeyExchangeParameters { /* private fields */ }Expand description
Typed wrapper for the SecKeyKeyExchangeParameter* dictionary accepted by LAPrivateKey::exchange_keys_with_public_key.
Implementations
Sourceimpl SecKeyExchangeParameters
impl SecKeyExchangeParameters
Sourcepub const fn with_requested_size(requested_size: usize) -> Self
pub const fn with_requested_size(requested_size: usize) -> Self
Create a dictionary that requests a derived key of the supplied length.
Sourcepub const fn requested_size(self, requested_size: usize) -> Self
pub const fn requested_size(self, requested_size: usize) -> Self
Override the requested derived-key length.
Attach additional shared info for algorithms that support KDF context data.
Clear any previously configured shared info.